==> nextcloud-29.0.12.tgz: nextcloud/apps/password_policy/l10n/zh_TW.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密碼已到期，請使用忘記密碼方式重設",
    "Password must not have been used recently before." : "密碼不可以是近期使用過的。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "密碼出現在 1,000,000 個常用密碼列表內。請設定獨一無二的密碼。",
    "Password is present in compromised password list. Please choose a different password." : "密碼出現在洩露的密碼清單中。請選擇其它密碼。",
    "Password needs to be at least %s characters long." : "密碼需長於 %s 個字母。",
    "Password needs to contain at least one numeric character." : "密碼需要包含至少一個數字。",
    "Password needs to contain at least one special character." : "密碼應包含一個特殊符號。",
    "Password needs to contain at least one lower and one upper case character." : "密碼應包含最少一個大寫與一個小寫字母。",
    "Password policy" : "密碼策略",
    "Allows admins to configure a password policy" : "讓管理員可以設定密碼策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允許管理員定義密碼的某些條件，例如強制最小長度",
    "General password policies" : "一般密碼政策",
    "Add policy set" : "新增政策集",
    "Login policies" : "登入政策",
    "Password history size" : "密碼歷史紀錄大小",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "要保留的密碼數量（安全雜湊值），以防止使用者重複使用先前使用過的密碼。",
    "Maximum login attempts" : "最大登入嘗試次數",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "在採取手動操作之前，使用者帳號將被停用先前的登入嘗試次數。 （0 表示無限制）",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "請注意，此選項是用來保護受攻擊的帳號。已停用的帳號必須由管理員手動重新啟用。嘗試猜測帳號密碼的攻擊者將透過與此設定無關的暴力保護來封鎖其 IP 位址。",
    "Number of days until user password expires" : "密碼到期天數",
    "Password expiration" : "密碼過期時間",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "警告：啟用密碼過期現在已被多家安全機構視為一種安全風險。",
    "Remove policy" : "移除政策",
    "Minimum password length" : "密碼最小長度",
    "Forbid common passwords" : "禁止常見的密碼",
    "Enforce upper and lower case characters" : "強制使用大寫與小寫字母",
    "Enforce numeric characters" : "強制使用數字字元",
    "Enforce special characters" : "強制使用特殊字元",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "將密碼與來自 haveibeenpwned.com 的外洩密碼列表進行核對",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "此項檢查會建立密碼的雜湊值，並傳送此雜湊值的前五個字元到 haveibeenpwned.com 的 API 來擷取以這些字元開頭的所有雜湊值列表。然後如果密碼雜湊值包含在結果集中，其將在 Nextcloud 站台上檢查。",
    "Account password policies" : "帳號密碼政策",
    "Share password policies" : "分享密碼政策",
    "User password history" : "使用者密碼歷史紀錄",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "請注意，此選項是用來保護受攻擊的帳號。已停用的帳號必須由管理員手動重新啟用。嘗試猜測帳號密碼的攻擊者將透過與此設定無關的暴力保護來封鎖其 IP 位址。",
    "Unknown error" : "未知錯誤",
    "Minimal length has to be a non negative number" : "最小長度必須為非負數",
    "History size has to be a non negative number" : "歷史紀錄大小必須為非負數",
    "Expiration days have to be a non negative number" : "到期天數必須為非負數",
    "Maximum login attempts have to be a non negative number" : "最大登入嘗試次數必須為非負數",
    "Settings saved" : "設定已儲存",
    "Error while saving settings" : "儲存設定時發生錯誤"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.12.tgz: nextcloud/apps/password_policy/l10n/zh_TW.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密碼已到期，請使用忘記密碼方式重設",
    "Password must not have been used recently before." : "密碼不可以是近期使用過的。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "密碼出現在 1,000,000 個常用密碼列表內。請設定獨一無二的密碼。",
    "Password is present in compromised password list. Please choose a different password." : "密碼出現在洩露的密碼清單中。請選擇其它密碼。",
    "Password needs to be at least %s characters long." : "密碼需長於 %s 個字母。",
    "Password needs to contain at least one numeric character." : "密碼需要包含至少一個數字。",
    "Password needs to contain at least one special character." : "密碼應包含一個特殊符號。",
    "Password needs to contain at least one lower and one upper case character." : "密碼應包含最少一個大寫與一個小寫字母。",
    "Password policy" : "密碼策略",
    "Allows admins to configure a password policy" : "讓管理員可以設定密碼策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允許管理員定義密碼的某些條件，例如強制最小長度",
    "General password policies" : "一般密碼政策",
    "Add policy set" : "新增政策集",
    "Login policies" : "登入政策",
    "Password history size" : "密碼歷史紀錄大小",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "要保留的密碼數量（安全雜湊值），以防止使用者重複使用先前使用過的密碼。",
    "Maximum login attempts" : "最大登入嘗試次數",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "在採取手動操作之前，使用者帳號將被停用先前的登入嘗試次數。 （0 表示無限制）",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "請注意，此選項是用來保護受攻擊的帳號。已停用的帳號必須由管理員手動重新啟用。嘗試猜測帳號密碼的攻擊者將透過與此設定無關的暴力保護來封鎖其 IP 位址。",
    "Number of days until user password expires" : "密碼到期天數",
    "Password expiration" : "密碼過期時間",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "警告：啟用密碼過期現在已被多家安全機構視為一種安全風險。",
    "Remove policy" : "移除政策",
    "Minimum password length" : "密碼最小長度",
    "Forbid common passwords" : "禁止常見的密碼",
    "Enforce upper and lower case characters" : "強制使用大寫與小寫字母",
    "Enforce numeric characters" : "強制使用數字字元",
    "Enforce special characters" : "強制使用特殊字元",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "將密碼與來自 haveibeenpwned.com 的外洩密碼列表進行核對",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "此項檢查會建立密碼的雜湊值，並傳送此雜湊值的前五個字元到 haveibeenpwned.com 的 API 來擷取以這些字元開頭的所有雜湊值列表。然後如果密碼雜湊值包含在結果集中，其將在 Nextcloud 站台上檢查。",
    "Account password policies" : "帳號密碼政策",
    "Share password policies" : "分享密碼政策",
    "Unknown error" : "未知錯誤",
    "Minimal length has to be a non negative number" : "最小長度必須為非負數",
    "History size has to be a non negative number" : "歷史紀錄大小必須為非負數",
    "Expiration days have to be a non negative number" : "到期天數必須為非負數",
    "Maximum login attempts have to be a non negative number" : "最大登入嘗試次數必須為非負數",
    "Settings saved" : "設定已儲存",
    "Error while saving settings" : "儲存設定時發生錯誤",
    "User password history" : "使用者密碼歷史紀錄"
},
"nplurals=1; plural=0;");
